@@ -15,7 +15,7 @@
 #define _ISOC99_SOURCE
 
 #include <string.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <sys/types.h>
 #include <sys/ioctl.h>
 #include <fcntl.h>
@@ -78,6 +78,8 @@ struct _GstCdparanoiaCDRomPrivate {
 
 	int check_playtime;
 	int end_playtime;
+
+	int volume;
 };
 
 static gboolean gst_cdparanoia_cdrom_eject (GnomeCDRom * cdrom,
@@ -208,6 +210,19 @@ eos (GstElement * element, gpointer data)
 	    (GstCdparanoiaCDRomPrivate *) data;*/
 }
 
+static gboolean
+stop_playback_idle_func (gpointer data) 
+{
+	GstCdparanoiaCDRomPrivate *priv =
+	    (GstCdparanoiaCDRomPrivate *) data;
+		    
+	gst_element_set_state (GST_ELEMENT (priv->play_thread),
+                               GST_STATE_NULL);
+	priv->check_playtime = 0;
+							  
+	return FALSE;
+}
+
 static void
 check_playtime (GstBin * bin, gpointer data)
 {
@@ -222,9 +237,7 @@ check_playtime (GstBin * bin, gpointer data)
 	    gst_pad_query (GST_PAD (priv->cdp_pad), GST_QUERY_POSITION,
 			   &priv->sector_format, &value);
 	if (ret && priv->check_playtime && value >= priv->end_playtime) {
-		gst_element_set_state (GST_ELEMENT (priv->play_thread),
-				       GST_STATE_NULL);
-		priv->check_playtime = 0;
+		g_idle_add (stop_playback_idle_func, data);
 	} else {
 		for (i = 0; i < priv->number_tracks; i++) {
 			if (value <
@@ -306,6 +319,8 @@ build_pipeline (GstCdparanoiaCDRom * lcd, GError ** error)
 	conv = gst_element_factory_make ("audioconvert", "conv");
 	scale = gst_element_factory_make ("audioscale", "scale");
 	priv->vol_element = vol = gst_element_factory_make ("volume", "vol");
+	g_object_set (G_OBJECT (priv->vol_element), "volume",
+		      (gdouble) priv->volume / 255.0, NULL);
 
 	/* Now build the pipeline */
 	gst_bin_add_many (GST_BIN (pthread), queue, conv,
@@ -1258,7 +1273,7 @@ gst_cdparanoia_cdrom_get_status (GnomeCDRom * cdrom,
 		return FALSE;
 
 	g_object_get (G_OBJECT (priv->vol_element), "volume", &vol, NULL);
-	realstatus->volume = lrint (vol * 255.0);
+	realstatus->volume = priv->volume = lrint (vol * 255.0);
 	cur_gst_status =
 	    gst_element_get_state (GST_ELEMENT (priv->play_thread));
 
@@ -1418,6 +1433,7 @@ gst_cdparanoia_cdrom_set_volume (GnomeCDRom * cdrom,
 
 	g_object_set (G_OBJECT (priv->vol_element), "volume",
 		      (gdouble) volume / 255.0, NULL);
+	priv->volume = volume;
 
 	return TRUE;
 }
