@@ -30,6 +30,7 @@
 #include <gst/mixer/mixer.h>
 #include <gst/propertyprobe/propertyprobe.h>
 
+#include "keys.h"
 #include "stock.h"
 #include "window.h"
 
@@ -92,6 +93,7 @@ create_mixer_collection (void)
     /* set all devices and test for mixer */
     for (n = 0; n < array->n_values; n++) {
       GValue *device = g_value_array_get_nth (array, n);
+      gchar *devname = NULL;
 
       /* set this device */
       g_object_set_property (G_OBJECT (element), "device", device);
@@ -114,14 +116,12 @@ create_mixer_collection (void)
       /* fetch name */
       if (g_object_class_find_property (G_OBJECT_GET_CLASS (G_OBJECT (element)),
 					"device-name")) {
-        gchar *devname;
         g_object_get (element, "device-name", &devname, NULL);
-        name = g_strdup_printf ("%s (%s)", devname,
-				gst_element_factory_get_longname (factory));
-      } else {
-        name = g_strdup_printf ("%s (%s)", title,
-				gst_element_factory_get_longname (factory));
       }
+
+      name = g_strdup_printf ("%s (%s)", devname ? devname : title,
+			      gst_element_factory_get_longname (factory));
+      g_free (devname);
       g_object_set_data (G_OBJECT (element), "gnome-volume-control-name",
 			 name);
 
@@ -131,6 +131,7 @@ create_mixer_collection (void)
       num++;
 
       /* and recreate this object, since we give it to the mixer */
+      g_free (title);
       title = g_strdup_printf (gettext("Unknown Volume Control %d"), num);
       element = gst_element_factory_create (factory, title);
     }
@@ -192,6 +193,19 @@ cb_destroy (GtkWidget *widget,
   gtk_main_quit ();
 }
 
+void
+cb_check_resize (GtkContainer    *container,
+      		  gpointer         user_data)
+{
+  GConfClient *client;
+  gint width, height;
+
+  client = gconf_client_get_default();
+  gtk_window_get_size (GTK_WINDOW (container), &width, &height);
+  gconf_client_set_int (client, PREF_UI_WINDOW_WIDTH, width, NULL);
+  gconf_client_set_int (client, PREF_UI_WINDOW_HEIGHT, height, NULL);
+}
+
 gint
 main (gint   argc,
       gchar *argv[])
@@ -260,6 +274,8 @@ main (gint   argc,
   /* window contains everything automagically */
   win = gnome_volume_control_window_new (elements);
   g_signal_connect (win, "destroy", G_CALLBACK (cb_destroy), NULL);
+  g_signal_connect (win, "check_resize", G_CALLBACK (cb_check_resize), NULL);
+
   gtk_widget_show (win);
   gtk_main ();
 
